@@ -52,7 +52,7 @@ func putUserPassword() {}
 // @Summary      用户列表
 // @Description  用户列表
 // @Tags         用户管理
-// @Accept       json
+// @Accept       application/x-www-form-urlencoded
 // @Param        page       query  int     false  "页码"    default(1)
 // @Param        page_size  query  int     false  "每页数量"  Enums(10, 20)  default(10)
 // @Param        username   query  string  false  "用户名"
@@ -68,7 +68,7 @@ func getUsers() {}
 // @Param        object  body  form.UserLogin  true  "参数"
 // @Produce      json
 // @Header       200  {string}  Authorization                  "鉴权"
-// @Success      200  {object}  query.Response{result=string}  "result 即 Authorization 参数，该值同时存在于 Header 的 Authorization 字段中"
+// @Success      200  {object}  query.Response{result=entity.User}  "result 即 Authorization 参数，该值同时存在于 Header 的 Authorization 字段中"
 // @Router       /user/login [post]
 func postUserLogin() {}
 
@@ -106,7 +106,7 @@ func deleteOperationLogs() {}
 // @Summary      获取操作日志
 // @Description  获取操作日志
 // @Tags         操作日志
-// @Accept       json
+// @Accept       application/x-www-form-urlencoded
 // @Security     ApiKeyAuth
 // @Deprecated   true
 // @Param        id  path  int  true  "ID"
@@ -118,7 +118,7 @@ func getOperationLog() {}
 // @Summary      获取操作日志列表
 // @Description  获取操作日志列表
 // @Tags         操作日志
-// @Accept       json
+// @Accept       application/x-www-form-urlencoded
 // @Security     ApiKeyAuth
 // @Param        page        query  int     false  "页码"    default(1)
 // @Param        page_size   query  int     false  "每页数量"  Enums(10, 20)  default(10)
@@ -128,13 +128,3 @@ func getOperationLog() {}
 // @Success      200  {object}  query.Response{result=Result{pager=form.Pager,list=[]query.OperationLogResult}}  "操作成功"
 // @Router       /operation_logs [get]
 func getOperationLogs() {}
-
-// @Summary      获取区域数据
-// @Description  获取区域数据
-// @Tags         常量数据
-// @Accept       application/x-www-form-urlencoded
-// @Param        code  query  string  false  "区域代码"
-// @Produce      json
-// @Success      200  {object}  query.Response{result=query.RegionLocation}  "操作成功"
-// @Router       /region/by [get]
-func getRegionBy() {}
